# 🚀 Easy Gateway

A simple to use and lightweight API Gateway for microservice architecture.

## ✨ Features

- ✅ Easy setup via YAML
- ✅ CLI interface
- ✅ Middleware system
- ✅ Routing with prefixes
- ✅ Rate limiting
- ✅ Logging

## 📦 Install



```bash
pip install easy-gateway
```
DOCS & HOW TO USE ON MY GITHUB:
[Visit It](https://github.com/MarkLevkovich/easy_gateway)
